@@ -1,6 +1,7 @@
-from .errors import BaseError, RateError, AuthError
+from .errors import BaseError, RateError, AuthError, SessionError, LoginError
 from .http_blueair import HttpBlueair
 from .http_aws_blueair import HttpAwsBlueair
 from .util_bootstrap import get_devices, get_aws_devices
 from .device import Device
 from .device_aws import DeviceAws
+from .model_enum import ModelEnum, FeatureEnum
