@@ -7,7 +7,7 @@ _LOGGER = logging.getLogger(__name__)
 
 def clean_dictionary_for_logging(dictionary: dict[str, any]) -> dict[str, any]:
     mutable_dictionary = dictionary.copy()
-    for key in dictionary.keys():
+    for key in dictionary:
         if key.lower() in SENSITIVE_FIELD_NAMES:
             mutable_dictionary[key] = "***"
         if type(mutable_dictionary[key]) is dict:
@@ -35,3 +35,19 @@ def convert_api_array_to_dict(array):
             if "vb" in obj:
                 dictionary[obj["n"]] = obj["vb"]
     return dictionary
+
+
+def safely_get_json_value(json, key, callable_to_cast=None):
+    value = json
+    for x in key.split("."):
+        if value is not None:
+            try:
+                value = value[x]
+            except (TypeError, KeyError):
+                try:
+                    value = value[int(x)]
+                except (TypeError, KeyError, ValueError):
+                    value = None
+    if callable_to_cast is not None and value is not None:
+        value = callable_to_cast(value)
+    return value
